/// This model class gives structure to a single repository
/// from the query which returns a list of them
class RepoModel {
  /// Cursor is the "id" by which we can make pagination possible,
  /// so you can think of it as an ID of the given repository
  String cursor;

  /// Repository name
  String name;

  /// This is a repository name with owner, already formatted
  /// in the username/repo-name format
  String longName;

  /// Description
  String description;

  /// This is the URL of the particular repository on GitHub and
  /// cannot be used for cloning via HTTP or SSH
  String url;

  /// Marks whether or not the repository is private
  bool isPrivate;

  /// Name of the primary language
  String languageName;

  /// Hex color code of the primary language
  String languageColor;

  /// Named constructor which initializes properties
  /// by deserializing [json]
  RepoModel.from(Map<String, dynamic> json) {
    this.cursor = json['cursor'];
    this.name = json['node']['name'];
    this.longName = json['node']['nameWithOwner'];
    this.description = json['node']['description'];
    this.url = json['node']['url'];
    this.isPrivate = json['node']['isPrivate'];
    this.languageName = json['node']['primaryLanguage']['name'];
    this.languageColor = json['node']['primaryLanguage']['color'];
  }
}
